exceptiontools.MissingPitchError
================================

.. abjad-lineage:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError

.. autoclass:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__unicode__
   :noindex:
